# Changelog

## 0.3.3 (2025-09-02)

Full Changelog: [v0.3.2...v0.3.3](https://github.com/miruml/python-server-sdk/compare/v0.3.2...v0.3.3)

### Features

* **api:** update via SDK Studio ([88789bd](https://github.com/miruml/python-server-sdk/commit/88789bd4aeec502c1423359460d0bbb3a85917b3))

## 0.3.2 (2025-09-02)

Full Changelog: [v0.3.1...v0.3.2](https://github.com/miruml/python-server-sdk/compare/v0.3.1...v0.3.2)

### Features

* **api:** update via SDK Studio ([deb3615](https://github.com/miruml/python-server-sdk/commit/deb361539226c1c44aa0504b40c837df9dd0fdee))


### Bug Fixes

* avoid newer type syntax ([bb04964](https://github.com/miruml/python-server-sdk/commit/bb049641ba3facb89a26fdaa0bdc815d7eaa2f3f))


### Chores

* **internal:** add Sequence related utils ([d536ef6](https://github.com/miruml/python-server-sdk/commit/d536ef6d0da7ca4cc3a1f81380516c45216be88f))
* **internal:** change ci workflow machines ([a939ac4](https://github.com/miruml/python-server-sdk/commit/a939ac43507104339efc9945767e3cfed5889e3d))
* **internal:** update pyright exclude list ([24f8ab2](https://github.com/miruml/python-server-sdk/commit/24f8ab2c020cb1a470f799d7f51f5b895ff2bf2c))

## 0.3.1 (2025-08-25)

Full Changelog: [v0.3.0...v0.3.1](https://github.com/miruml/python-server-sdk/compare/v0.3.0...v0.3.1)

### Features

* **api:** update via SDK Studio ([9ee993c](https://github.com/miruml/python-server-sdk/commit/9ee993cd4a38a8b2f84913cdbc19a073ee485e3f))

## 0.3.0 (2025-08-25)

Full Changelog: [v0.3.0-beta.3...v0.3.0](https://github.com/miruml/python-server-sdk/compare/v0.3.0-beta.3...v0.3.0)

### Chores

* hardset the miru-server-sdk for example dependencies ([ab53767](https://github.com/miruml/python-server-sdk/commit/ab53767fbedbcda268f415fd155d9448d0c3a1a1))

## 0.3.0-beta.3 (2025-08-25)

Full Changelog: [v0.3.0-beta.2...v0.3.0-beta.3](https://github.com/miruml/python-server-sdk/compare/v0.3.0-beta.2...v0.3.0-beta.3)

### Refactors

* webhook unwrapping to use 'Any' instead of string ([9554da7](https://github.com/miruml/python-server-sdk/commit/9554da7c959014f99d14dc3715ea80998b15815e))
* webhook unwrapping to use 'Any' instead of string ([cb20d0f](https://github.com/miruml/python-server-sdk/commit/cb20d0f0a7c3010cd7a84f19c8fc502c19690963))

## 0.3.0-beta.2 (2025-08-25)

Full Changelog: [v0.3.0-beta.1...v0.3.0-beta.2](https://github.com/miruml/python-server-sdk/compare/v0.3.0-beta.1...v0.3.0-beta.2)

### Features

* **api:** update via SDK Studio ([7a8a1ed](https://github.com/miruml/python-server-sdk/commit/7a8a1ed569ef29bdbaa01af5e2680ccf43aca69d))

## 0.3.0-beta.1 (2025-08-25)

Full Changelog: [v0.3.0-beta...v0.3.0-beta.1](https://github.com/miruml/python-server-sdk/compare/v0.3.0-beta...v0.3.0-beta.1)

### Features

* **api:** update via SDK Studio ([31cf9fd](https://github.com/miruml/python-server-sdk/commit/31cf9fdfdab2ff8d95a6b05c61e048504cbcf1c8))
* **api:** update via SDK Studio ([1d84dfb](https://github.com/miruml/python-server-sdk/commit/1d84dfb2587b25c4d31b5091a22b4465b03633b8))

## 0.3.0-beta (2025-08-24)

Full Changelog: [v0.2.0...v0.3.0-beta](https://github.com/miruml/python-server-sdk/compare/v0.2.0...v0.3.0-beta)

### Features

* **api:** update via SDK Studio ([b0c3b7b](https://github.com/miruml/python-server-sdk/commit/b0c3b7b716d837c4c2487877946a45fe887466bc))
* **api:** update via SDK Studio ([94bb30b](https://github.com/miruml/python-server-sdk/commit/94bb30b2a1a1f9bdd4e17ebe3680341d1c540cb7))
* **api:** update via SDK Studio ([c22dccb](https://github.com/miruml/python-server-sdk/commit/c22dccb6ef9fe5d389b639e1d3fd2a6118df4964))
* **api:** update via SDK Studio ([8b22204](https://github.com/miruml/python-server-sdk/commit/8b222048fc2719b302514f00147d19fa472390f4))
* **api:** update via SDK Studio ([030cdaf](https://github.com/miruml/python-server-sdk/commit/030cdafbd390137175d528d521563a517f20e11d))
* **api:** update via SDK Studio ([31245e0](https://github.com/miruml/python-server-sdk/commit/31245e0478282fd91a344a2c6561939f9b74392f))
* **api:** update via SDK Studio ([a3202e1](https://github.com/miruml/python-server-sdk/commit/a3202e1c342b2b4871740d5755f98c7391568a6b))
* **api:** update via SDK Studio ([808abb8](https://github.com/miruml/python-server-sdk/commit/808abb81933f8f40bc9693ba587ceeeeebd5bb7b))
* **api:** update via SDK Studio ([5c22d6d](https://github.com/miruml/python-server-sdk/commit/5c22d6d8ee1f5e4eb73cd4a84d2366ba2f8f7a2b))


### Bug Fixes

* add webhook module to be importable ([ecfb9fd](https://github.com/miruml/python-server-sdk/commit/ecfb9fdd0f8e1987008c4d27bfb40bafd2d1f104))
* linter errors ([640ca58](https://github.com/miruml/python-server-sdk/commit/640ca58aac05c890aabde49b8f2d877b5858fa79))
* pydantic linter error ([3831831](https://github.com/miruml/python-server-sdk/commit/38318313558b5c8bce375891f27baaa12014c0bb))
* remove support for pydantic v1 ([bd1c3c7](https://github.com/miruml/python-server-sdk/commit/bd1c3c783706c79e47c3392b97b790cb79f24195))


### Chores

* add examples ([6412a8f](https://github.com/miruml/python-server-sdk/commit/6412a8fc5efa0920e3e67d547bc438576552ebfd))
* configure new SDK language ([24c68b0](https://github.com/miruml/python-server-sdk/commit/24c68b06eb9f987361581ea160e29b5be95cba13))
* refactor examples to be more clear ([09be5cc](https://github.com/miruml/python-server-sdk/commit/09be5cc02ba45b96586a8e9247017c9ae4cd6f84))
* update examples to import API from .env file ([acb9caf](https://github.com/miruml/python-server-sdk/commit/acb9cafa95aea053a465fc6a7e5e0311ced520a2))
* update SDK settings ([b3672dc](https://github.com/miruml/python-server-sdk/commit/b3672dc0d33501047bab49f9efe2ca0f4b10c63a))
* update SDK settings ([47a4b89](https://github.com/miruml/python-server-sdk/commit/47a4b895060372460a0681376a0fcb18807a6ffb))


### Refactors

* rollback stainless' auto semver ([562fc80](https://github.com/miruml/python-server-sdk/commit/562fc80bac0fde2950acecdc660ba3237975c737))

## 0.2.1 (2025-08-22)

Full Changelog: [v0.0.1...v0.2.1](https://github.com/miruml/python-server-sdk/compare/v0.0.1...v0.2.1)

### Features

* **api:** update via SDK Studio ([a3202e1](https://github.com/miruml/python-server-sdk/commit/a3202e1c342b2b4871740d5755f98c7391568a6b))
* **api:** update via SDK Studio ([808abb8](https://github.com/miruml/python-server-sdk/commit/808abb81933f8f40bc9693ba587ceeeeebd5bb7b))
* **api:** update via SDK Studio ([5c22d6d](https://github.com/miruml/python-server-sdk/commit/5c22d6d8ee1f5e4eb73cd4a84d2366ba2f8f7a2b))


### Chores

* configure new SDK language ([24c68b0](https://github.com/miruml/python-server-sdk/commit/24c68b06eb9f987361581ea160e29b5be95cba13))
* update SDK settings ([b3672dc](https://github.com/miruml/python-server-sdk/commit/b3672dc0d33501047bab49f9efe2ca0f4b10c63a))
* update SDK settings ([47a4b89](https://github.com/miruml/python-server-sdk/commit/47a4b895060372460a0681376a0fcb18807a6ffb))
